==> haskell-pcre-light-0.4.0.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-light
version: 0.4.0.4
id: pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0
key: pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0
license: BSD-3-Clause
copyright: (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer: Daniel Díaz <dhelta.diaz@gmail.com>
author: Don Stewart
homepage: https://github.com/Daniel-Diaz/pcre-light
synopsis: Portable regex library for Perl 5 compatible regular expressions
description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions
    .
    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.
    .
    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux).
    .
category: Text
abi: 8201cf7a2cbd2134b29948f1cf78d17d
exposed: True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8
import-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-light-0.4.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-light-0.4.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pcre-light-0.4.0.4
hs-libraries: HSpcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0
extra-libraries:
    pcre
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html: /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-light-0.4.0.4-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-light
version: 0.4.0.4
id: pcre-light-0.4.0.4-8zfbmBbUiMjItZRXBeQFXh
key: pcre-light-0.4.0.4-8zfbmBbUiMjItZRXBeQFXh
license: BSD-3-Clause
copyright: (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer: Daniel Díaz <dhelta.diaz@gmail.com>
author: Don Stewart
homepage: https://github.com/Daniel-Diaz/pcre-light
synopsis: Portable regex library for Perl 5 compatible regular expressions
description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions
    .
    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.
    .
    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux).
    .
category: Text
abi: 6c9a8841647be2e693251401c7bf79c2
exposed: True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Base
    Text.Regex.PCRE.Light.Char8
import-dirs: /usr/lib/ghc-8.6.1/site-local/pcre-light-0.4.0.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/pcre-light-0.4.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/pcre-light-0.4.0.4
hs-libraries: HSpcre-light-0.4.0.4-8zfbmBbUiMjItZRXBeQFXh
extra-libraries:
    pcre
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html: /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
